#include <iostream>
#include <vector>
#include <algorithm>
#include <unordered_set>

struct Participant {
    int id;
    std::string gender;
    int grade;
    int age;
    int score;
};

bool compareByScore(const Participant& a, const Participant& b) {
    return a.score > b.score;
}

bool compareByAge(const Participant& a, const Participant& b) {
    return a.age < b.age;
}

bool compareById(const Participant& a, const Participant& b) {
    return a.id < b.id;
}

bool compareByGradeAndId(const Participant& a, const Participant& b) {
    if (a.grade != b.grade) {
        return a.grade < b.grade;
    }
    return a.id < b.id;
}

int main() {
    int n;
    std::cin >> n;

    std::vector<Participant> participants(n);

    for (int i = 0; i < n; ++i) {
        std::cin >> participants[i].id >> participants[i].gender >> participants[i].grade
                 >> participants[i].age >> participants[i].score;
    }

    std::vector<Participant> sortedParticipants = participants;
    std::sort(sortedParticipants.begin(), sortedParticipants.end(), compareById);

    int m;
    std::cin >> m;

    while (m--) {
        std::string olympiad;
        std::cin >> olympiad;

        std::vector<Participant> team;

        if (olympiad == "IOI" || olympiad == "CEOI") {
            std::sort(sortedParticipants.begin(), sortedParticipants.end(), compareByScore);
            team.insert(team.end(), sortedParticipants.begin(), sortedParticipants.begin() + std::min(4, n));
        } else if (olympiad == "EGOI") {
            std::sort(sortedParticipants.begin(), sortedParticipants.end(), compareByGradeAndId);
            auto it = std::remove_if(sortedParticipants.begin(), sortedParticipants.end(), [](const Participant& p) {
                return p.gender != "female";
            });
            sortedParticipants.erase(it, sortedParticipants.end());
            team.insert(team.end(), sortedParticipants.begin(), sortedParticipants.begin() + std::min(4, static_cast<int>(sortedParticipants.size())));
        } else if (olympiad == "EJOI") {
            std::sort(sortedParticipants.begin(), sortedParticipants.end(), compareByAge);
            team.insert(team.end(), sortedParticipants.begin(), sortedParticipants.begin() + std::min(4, n));
        } else if (olympiad == "BaltOI") {
            std::sort(sortedParticipants.begin(), sortedParticipants.end(), compareByGradeAndId);
            team.insert(team.end(), sortedParticipants.begin(), sortedParticipants.begin() + std::min(6, n));
        } else if (olympiad == "BalkOI") {
            std::sort(sortedParticipants.begin(), sortedParticipants.end(), compareByGradeAndId);
            auto it = std::remove_if(sortedParticipants.begin(), sortedParticipants.end(), [](const Participant& p) {
                return p.grade == 11;
            });
            sortedParticipants.erase(it, sortedParticipants.end());
            team.insert(team.end(), sortedParticipants.begin(), sortedParticipants.begin() + std::min(4, static_cast<int>(sortedParticipants.size())));
        } else if (olympiad == "JBOI") {
            std::sort(sortedParticipants.begin(), sortedParticipants.end(), compareByGradeAndId);
            auto it = std::remove_if(sortedParticipants.begin(), sortedParticipants.end(), [](const Participant& p) {
                return p.grade == 10 || p.grade == 11;
            });
            sortedParticipants.erase(it, sortedParticipants.end());
            team.insert(team.end(), sortedParticipants.begin(), sortedParticipants.begin() + std::min(4, static_cast<int>(sortedParticipants.size())));
        }

        // Output the team composition
        std::cout << olympiad << std::endl;
        std::sort(team.begin(), team.end(), compareById);
        std::unordered_set<int> usedIds;
        for (const auto& participant : team) {
            if (usedIds.find(participant.id) == usedIds.end()) {
                std::cout << participant.id << std::endl;
                usedIds.insert(participant.id);
            }
        }
    }

    return 0;
}
