from collections import defaultdict

def form_team(participants, criteria):
    # Sort participants based on the specified criteria
    sorted_participants = sorted(participants, key=criteria, reverse=True)
    
    # Return the top 4 (or less if there are fewer participants) for the team
    return sorted_participants[:min(4, len(sorted_participants))]

def IOI_criteria(participant):
    return participant['score']

def CEOI_criteria(participant):
    return participant['score']

def EGOI_criteria(participant):
    return (participant['gender'] == 'female', participant['score'])

def EJOI_criteria(participant):
    return (participant['age'] <= 15, participant['score'])

def BaltOI_criteria(participant):
    return participant['score']

def BalkOI_criteria(participant):
    return (participant['grade'] != 11, participant['score'])

def JBOI_criteria(participant):
    return (participant['grade'] not in {10, 11}, participant['score'])

# Mapping between olympiad names and their corresponding criteria functions
criteria_mapping = {
    'IOI': IOI_criteria,
    'CEOI': CEOI_criteria,
    'EGOI': EGOI_criteria,
    'EJOI': EJOI_criteria,
    'BaltOI': BaltOI_criteria,
    'BalkOI': BalkOI_criteria,
    'JBOI': JBOI_criteria,
}

# Read input data
n = int(input())
participants = []
for _ in range(n):
    id, gender, grade, age, score = map(int, input().split())
    participants.append({'id': id, 'gender': gender, 'grade': grade, 'age': age, 'score': score})

m = int(input())
olympiads = [input().strip() for _ in range(m)]

# Form teams for each specified olympiad
teams = defaultdict(list)
for olympiad in olympiads:
    criteria_function = criteria_mapping[olympiad]
    teams[olympiad] = form_team(participants, criteria_function)

# Print the results
for olympiad in olympiads:
    print(olympiad)
    for participant in sorted(teams[olympiad], key=lambda x: x['id']):
        print(participant['id'])
