def choose_colors(n, m, a):
  """
  Returns the maximum length of the sequence of unmarked colors before Miss M selects the (m+1)-th color.

  Args:
    n: The number of color wheels.
    m: The number of colors Miss M wants to take additionally.
    a: A list of integers, where ai is the number of colors on the i-th color wheel.

  Returns:
    The maximum length of the sequence of unmarked colors before Miss M selects the (m+1)-th color.
  """

  # Create a list to store the lengths of the sequences of unmarked colors for each color wheel.
  lengths = [ai for ai in a]

  # While Miss M has not chosen all the colors she wants, keep choosing the longest sequence of unmarked colors.
  while m > 0:
    # Find the longest sequence of unmarked colors.
    max_length = max(lengths)

    # If the length of the longest sequence is odd, choose the color in the middle.
    if max_length % 2 == 1:
      middle = max_length // 2
      for i in range(n):
        if lengths[i] == max_length:
          lengths[i] = middle
          break
    # Otherwise, choose one of the two middle colors.
    else:
      middle = max_length // 2 - 1
      for i in range(n):
        if lengths[i] == max_length:
          lengths[i] = middle
          break

    # Decrement the number of colors Miss M wants to choose.
    m -= 1

  # Return the maximum length of the sequence of unmarked colors before Miss M selects the (m+1)-th color.
  return max(lengths)


def main():
  """Reads the input and prints the answer."""

  n, m = map(int, input().split())
  a = list(map(int, input().split()))

  answer = choose_colors(n, m, a)
  print(answer)


if __name__ == '__main__':
  main()
