class ColorWheel:
    """
    Class to represent a color wheel.

    Attributes:
    - colors: list
        List of colors in the color wheel.
    - initial_color: str
        The initial color selected on the color wheel.
    """

    def __init__(self, colors: list, initial_color: str):
        """
        Constructor to instantiate the ColorWheel class.

        Parameters:
        - colors: list
            List of colors in the color wheel.
        - initial_color: str
            The initial color selected on the color wheel.
        """

        self.colors = colors
        self.initial_color = initial_color


def choose_harmonious_colors(color_wheels: list) -> list:
    """
    Function to choose harmonious colors from the given color wheels.

    Parameters:
    - color_wheels: list
        List of ColorWheel objects representing the color wheels.

    Returns:
    - list:
        List of harmonious colors chosen from the color wheels.
    """

    harmonious_colors = []

    # Iterate through each color wheel
    for wheel in color_wheels:
        # Get the initial color of the wheel
        initial_color = wheel.initial_color

        # Find the complementary color of the initial color
        complementary_color = find_complementary_color(initial_color)

        # Add the complementary color to the list of harmonious colors
        harmonious_colors.append(complementary_color)

    return harmonious_colors


def find_complementary_color(color: str) -> str:
    """
    Function to find the complementary color of a given color.

    Parameters:
    - color: str
        The color for which the complementary color needs to be found.

    Returns:
    - str:
        The complementary color of the given color.
    """

    # Dictionary mapping colors to their complementary colors
    complementary_colors = {
        "red": "cyan",
        "green": "magenta",
        "blue": "yellow",
        "cyan": "red",
        "magenta": "green",
        "yellow": "blue"
    }

    # Return the complementary color if it exists in the dictionary, otherwise return None
    return complementary_colors.get(color)


# Example usage:

# Create color wheels
color_wheel1 = ColorWheel(["red", "orange", "yellow"], "red")
color_wheel2 = ColorWheel(["green", "blue", "purple"], "green")
color_wheel3 = ColorWheel(["cyan", "magenta", "yellow"], "cyan")

# Choose harmonious colors
harmonious_colors = choose_harmonious_colors([color_wheel1, color_wheel2, color_wheel3])

# Print the chosen harmonious colors
print("Harmonious colors:")
for color in harmonious_colors:
    print(color)