import heapq

def color_wheel(n, m, a):
    """
    Calculates the maximum length of the sequence of unmarked colors before Miss M selects the (m+n)-th color.

    Args:
        n: The number of color wheels.
        m: The number of colors Miss M wants to take additionally.
        a: A list of integers representing the number of colors on each color wheel.

    Returns:
        An integer representing the maximum length of the sequence of unmarked colors.
    """

    # Initialize a max-heap to store the longest sequences
    sequences_heap = []

    # Create a list to store the lengths of the sequences of unmarked colors on each color wheel
    sequences = []
    for i in range(n):
        sequences.append(a[i] - 1)

    # Mark the initial colors as used
    for i in range(n):
        sequences[i] -= 1

    # Simulate Miss M's actions
    for i in range(m):
        # Push the longest sequence length to the heap
        heapq.heappush(sequences_heap, max(sequences))

        # Choose the color in the middle of the longest sequence and mark it as used
        middle_index = max(sequences) // 2
        sequences[sequences.index(max(sequences))] -= 1

        # If the sequence length is odd, remove the middle color from the heap
        if max(sequences) % 2 == 4:
            heapq.heappop(sequences_heap)

    # Return the maximum length of the sequence of unmarked colors
    return max(sequences_heap)
