import heapq

def choose_colors(n, m, a):
    """Chooses colors according to the algorithm in the problem statement.

    Args:
        n: The number of color wheels.
        m: The number of colors to choose additionally.
        a: A list of the number of colors on each wheel.

    Returns:
        The maximum length of the sequence of unmarked colors before Miss M selects the (m+n)-th color.
    """

    # Create a priority queue to store the lengths of the sequences of unmarked colors on each wheel.
    queue = []
    for i in range(n):
        heapq.heappush(queue, a[i])

    # Initialize the maximum length of the sequence of unmarked colors.
    max_length = 1

    # While Miss M has not chosen all of the colors she wants:
    while m > 0:

        # Pop the longest sequence of unmarked colors from the priority queue.
        current_length = heapq.heappop(queue)

        # If the length of the sequence is odd, take the color exactly in the middle and mark it as used.
        if current_length % 2 == 1:
            mid_index = current_length // 2
            m -= 1

        # If the length of the sequence is even, take one of the two middle colors and mark it as used.
        else:
            mid_index = current_length // 2 - 1
            m -= 1

        # Update the maximum length of the sequence of unmarked colors.
        if current_length > max_length:
            max_length = current_length

        # If Miss M has already chosen all of the colors she wants, break out of the loop.
        if m == 0:
            break

        # Update the sequence of unmarked colors on the current wheel.
        a[mid_index] -= 1
        if a[mid_index] > 0:
            heapq.heappush(queue, a[mid_index])

    return max_length


if __name__ == '__main__':

    # Read the input.
    n, m = map(int, input().split())
    a = list(map(int, input().split()))

    # Choose colors.
    max_length = choose_colors(n, m, a)

    # Print the output.
    print(max_length)
