#include <iostream>
#include <vector>
#include <algorithm>

struct Football {
    int color;
    int size;
};

int main() {
    int n, m;
    std::cin >> n >> m;

    std::vector<std::string> sizes(m);
    for (int i = 0; i < m; ++i) {
        std::cin >> sizes[i];
    }

    std::vector<std::vector<int>> available(n, std::vector<int>(m));
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            std::cin >> available[i][j];
        }
    }

    int k;
    std::cin >> k;

    std::vector<Football> requests(k);
    for (int i = 0; i < k; ++i) {
        int color;
        char size;
        std::cin >> color >> size;
        requests[i] = {color, std::find(sizes.begin(), sizes.end(), std::string(1, size)) - sizes.begin()};
    }

    // Sorting the requests in the order they are given
    std::sort(requests.begin(), requests.end(), [](const Football& a, const Football& b) {
        return a.color < b.color;
    });

    // Process each request
    for (const auto& request : requests) {
        int color = request.color - 1;
        int size = request.size;

        // Check if the requested size and color is available
        if (available[color][size] > 0) {
            --available[color][size];
        } else {
            // Find a suitable replacement according to the algorithm
            for (int i = size + 1; i < m; ++i) {
                if (available[color][i] > 0) {
                    --available[color][i];
                    break;
                }
            }
        }
    }

    // Print the remaining available and required footballs
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            std::cout << available[i][j] << ' ';
        }
        std::cout << '\n';
    }

    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            // Calculate the number of required footballs
            int required = std::max(0, available[i][j] - requests.size());
            std::cout << required << ' ';
        }
        std::cout << '\n';
    }

    return 0;
}
