# Часть 4.1: analyzer.py

import re
from collections import Counter
from typing import List, Tuple


def analyze_text(file_path: str) -> List[Tuple[str, int]]:
    """
    Анализирует текстовый файл и возвращает список кортежей (слово, частота встречаемости).
    """
    with open(file_path, 'r', encoding='utf-8') as file:
        text = file.read().lower()  # Преобразуем весь текст в нижний регистр
        words = re.findall(r'\b\w+\b', text)  # Разбиваем текст на слова
        word_count = Counter(words)  # Подсчитываем частоту встречаемости слов

    return word_count.most_common()


# Часть 4.2: main.py

from analyzer import analyze_text

def main():
    file_path = 'sample.txt'  # Путь к текстовому файлу
    result = analyze_text(file_path)

    # Выводим наиболее часто встречающиеся слова
    for word, count in result:
        print(f'{word}: {count} раз')

if __name__ == "__main__":
    main()

# Часть 4.3: tests/test_analyzer.py

from analyzer import analyze_text

def test_analyze_text():
    # Подготовка временного текстового файла для теста
    with open('test_file.txt', 'w', encoding='utf-8') as test_file:
        test_file.write("test text for testing analyzer. Testing is important!")

    result = analyze_text('test_file.txt')
    expected_result = [('testing', 2), ('test', 2), ('is', 1), ('important', 1), ('analyzer', 1), ('for', 1)]

    assert result == expected_result

# Часть 4.4: Запуск тестов
# В командной строке выполняем команду: pytest tests/test_analyzer.py

# Часть 4.5: Пример использования в main.py
# Запускаем main.py: python main.py

# Часть 4.6: Вывод
# Программа успешно анализирует текстовый файл и выводит список наиболее часто встречающихся слов.

