#include <iostream>
#include <vector>
#include <unordered_map>
#include <tuple>
#include <algorithm>

struct Tshirt {
    std::string color;
    char size;
    Tshirt(std::string c, char s) : color(std::move(c)), size(s) {}
};

int main() {
    int n, m, k;
    std::cin >> n >> m;

    std::vector<std::string> sizes(m);
    for (auto &size : sizes) std::cin >> size;

    std::vector<std::vector<int>> inStock(n, std::vector<int>(m));
    for (auto &stock : inStock) for (auto &count : stock) std::cin >> count;

    std::unordered_map<std::string, int> colorIndex;
    std::vector<Tshirt> stock, needed;

    for (int i = 0; i < n; ++i) {
        std::string color;
        std::cin >> color;
        colorIndex[color] = i;
    }

    auto findTshirt = [&](const std::string &color, char size) -> std::tuple<bool, int, char> {
        int colorIdx = colorIndex[color];

        auto it = std::find_if(sizes.begin(), sizes.end(), [&](const std::string &s) { return s == std::string(1, size); });
        int sizeIdx = (it != sizes.end()) ? std::distance(sizes.begin(), it) : -1;

        if (sizeIdx != -1 && inStock[colorIdx][sizeIdx]-- > 0) {
            stock.emplace_back(color, size);
            return {true, -1, ' '};
        }

        for (int j = 0; j < n; ++j) if (inStock[j][sizeIdx]-- > 0) {
            stock.emplace_back(std::to_string(j), size);
            return {true, -1, ' '};
        }

        for (int j = sizeIdx + 1; j < m; ++j)
            for (int i = 0; i < n; ++i)
                if (inStock[i][j]-- > 0) {
                    stock.emplace_back(std::to_string(i), sizes[j][0]); // Corrected here
                    return {true, -1, ' '};
                }

        return {false, colorIdx, size};
    };

    std::cin >> k;
    for (int i = 0; i < k; ++i) {
        std::string color;
        char size;
        std::cin >> color >> size;

        auto [found, colorIdx, newSize] = findTshirt(color, size);
        if (!found) needed.emplace_back(std::to_string(colorIdx), newSize);
    }

    for (const auto &stockRow : inStock) {
        for (int count : stockRow) std::cout << count << ' ';
        std::cout << '\n';
    }

    for (const auto &neededShirt : needed) {
        std::cout << neededShirt.color << ' ' << neededShirt.size << '\n';
    }

    return 0;
}



