def parse_input():
    n = int(input())
    participants = []
    for _ in range(n):
        id, gender, grade, age, score = input().strip().split()
        participants.append({
            'id': int(id),
            'gender': gender,
            'grade': int(grade),
            'age': int(age),
            'score': int(score)
        })
    m = int(input())
    olympiads = [input().strip() for _ in range(m)]
    return participants, olympiads

# Coming from a logical programming background, I decided to represent it as a predicate satisfaction problem.
# Each olympiad has a predicate that represents if a student can participate. I then use filters and maps to find the matching solutions.
ioi_predicate = lambda participant: True
egoi_predicate = lambda participant: participant['gender'] == 'female'
ejoi_predicate = lambda participant: participant['age'] <= 15
baltoi_predicate = lambda participant: True
balkoi_predicate = lambda participant: participant['grade'] != 11
jboi_predicate = lambda participant: participant['grade'] not in [10, 11]

# Dictionary mapping olympiad names to their respective predicates and team sizes
olympiad_info = {
    'IOI':       {'predicate': ioi_predicate,     'team_size': 4},
    'CEOI':      {'predicate': ioi_predicate,     'team_size': 4},
    'EGOI':      {'predicate': egoi_predicate,    'team_size': 4},
    'EJOI':      {'predicate': ejoi_predicate,    'team_size': 4},
    'BaltOI':    {'predicate': baltoi_predicate,  'team_size': 6},
    'BalkOI':    {'predicate': balkoi_predicate,  'team_size': 4},
    'JBOI':      {'predicate': jboi_predicate,    'team_size': 4},
}

def select_team(olympiad, participants):
    # Filter out the participants who meet olympiad criteria and sort by score
    valid_participants = sorted(
        filter(olympiad_info[olympiad]['predicate'], participants),
        key=lambda x: -x['score']
    )

    # Select top participants based on team size or available participants
    team_size = olympiad_info[olympiad]['team_size']
    team = [participant['id'] for participant in valid_participants[:team_size]]
    return team

def main():
    participants, olympiads = parse_input()
    
    # Now all that's left is printing.
    for i, olympiad in enumerate(olympiads):
        team = select_team(olympiad, participants)
        print(olympiad)
        for participant_id in sorted(team):
            print(participant_id)
        if i < len(olympiads) - 1:
            print()

if __name__ == "__main__":
    main()