def choose_color(color_sequences, m, depth=0, max_seq_length=0):
    if depth == m:
        # We've chosen m colors, return the max sequence length found so far
        return max_seq_length

    longest_seqs = [max(color_sequences, key=len)]
    longest_length = len(longest_seqs[0])

    max_seq_length = max(max_seq_length, longest_length)

    # Backtracking: Try to mark a color from the longest sequences
    for seq in longest_seqs:
        new_seq = list(seq)
        mid = len(new_seq) // 2

        # If even length, we could choose either of the two middle ones
        if longest_length % 2 == 0:
            # Choose the first middle one (arbitrary decision)
            new_seq.pop(mid - 1)
        else:
            # Choose the middle one
            new_seq.pop(mid)

        # Divide into two sequences and continue
        left_seq = new_seq[:mid - 1]
        right_seq = new_seq[mid:]

        # Filter out empty sequences
        new_color_sequences = [s for s in color_sequences if s != seq]
        if left_seq:
            new_color_sequences.append(left_seq)
        if right_seq:
            new_color_sequences.append(right_seq)

        current_max = choose_color(new_color_sequences, m, depth + 1, max_seq_length)
        max_seq_length = max(max_seq_length, current_max)

    return max_seq_length


def to_sequences(a):
    """Convert the color wheel counts into sequences representing unmarked colors"""
    return [[0] * (ai - 1) for ai in a]


n, m = map(int, input().split())
color_wheel_counts = list(map(int, input().split()))

initial_sequences = to_sequences(color_wheel_counts)

result = choose_color(initial_sequences, m)
print(result+1)