using System;
using System.Collections.Generic;

class Program
{
    static void Main(string[] args)
    {
        int n = int.Parse(Console.ReadLine());
        Dictionary<string, List<string>> participants = new Dictionary<string, List<string>>();

        for (int i = 0; i < n; i++)
        {
            string[] participantInfo = Console.ReadLine().Split();
            string id = participantInfo[0];
            string gender = participantInfo[1];
            int grade = int.Parse(participantInfo[2]);
            int age = int.Parse(participantInfo[3]);
            int score = int.Parse(participantInfo[4]);

            if (!participants.ContainsKey(id))
            {
                participants[id] = new List<string>();
            }

            participants[id].Add($"{score} {gender} {grade} {age}");
        }

        int m = int.Parse(Console.ReadLine());

        for (int i = 0; i < m; i++)
        {
            string olympiad = Console.ReadLine();
            List<string> team = new List<string>();

            switch (olympiad)
            {
                case "IOI":
                case "CEOI":
                case "BaltOI":
                    team = GetTopParticipants(participants, 4);
                    break;
                case "EGOI":
                    team = GetTopFemaleParticipants(participants, 4);
                    break;
                case "EJOI":
                    team = GetTopYoungParticipants(participants, 4);
                    break;
                case "BalkOI":
                    team = GetTopNon11thGradeParticipants(participants, 4);
                    break;
                case "JBOI":
                    team = GetTopNon11thOr10thGradeParticipants(participants, 4);
                    break;
            }

            Console.WriteLine(olympiad);

            foreach (string participant in team)
            {
                Console.WriteLine(participant);
            }
        }
    }

    static List<string> GetTopParticipants(Dictionary<string, List<string>> participants, int count)
    {
        List<string> topParticipants = new List<string>();

        foreach (var participant in participants)
        {
            List<string> participantInfo = participant.Value;
            participantInfo.Sort();
            participantInfo.Reverse();

            for (int i = 0; i < Math.Min(count, participantInfo.Count); i++)
            {
                topParticipants.Add(participant.Key);
            }
        }

        topParticipants.Sort();
        return topParticipants;
    }

    static List<string> GetTopFemaleParticipants(Dictionary<string, List<string>> participants, int count)
    {
        List<string> topFemaleParticipants = new List<string>();

        foreach (var participant in participants)
        {
            List<string> participantInfo = participant.Value;
            participantInfo.Sort();
            participantInfo.Reverse();

            foreach (string info in participantInfo)
            {
                string[] infoParts = info.Split();
                string gender = infoParts[1];

                if (gender == "female")
                {
                    topFemaleParticipants.Add(participant.Key);
                    break;
                }
            }
        }

        topFemaleParticipants.Sort();
        return topFemaleParticipants;
    }

    static List<string> GetTopYoungParticipants(Dictionary<string, List<string>> participants, int count)
    {
        List<string> topYoungParticipants = new List<string>();

        foreach (var participant in participants)
        {
            List<string> participantInfo = participant.Value;
            participantInfo.Sort();
            participantInfo.Reverse();

            foreach (string info in participantInfo)
            {
                string[] infoParts = info.Split();
                int age = int.Parse(infoParts[3]);

                if (age <= 15)
                {
                    topYoungParticipants.Add(participant.Key);
                    break;
                }
            }
        }

        topYoungParticipants.Sort();
        return topYoungParticipants;
    }

    static List<string> GetTopNon11thGradeParticipants(Dictionary<string, List<string>> participants, int count)
    {
        List<string> topNon11thGradeParticipants = new List<string>();

        foreach (var participant in participants)
        {
            List<string> participantInfo = participant.Value;
            participantInfo.Sort();
            participantInfo.Reverse();

            foreach (string info in participantInfo)
            {
                string[] infoParts = info.Split();
                int grade = int.Parse(infoParts[2]);

                if (grade != 11)
                {
                    topNon11thGradeParticipants.Add(participant.Key);
                    break;
                }
            }
        }

        topNon11thGradeParticipants.Sort();
        return topNon11thGradeParticipants;
    }

    static List<string> GetTopNon11thOr10thGradeParticipants(Dictionary<string, List<string>> participants, int count)
    {
        List<string> topNon11thOr10thGradeParticipants = new List<string>();

        foreach (var participant in participants)
        {
            List<string> participantInfo = participant.Value;
            participantInfo.Sort();
            participantInfo.Reverse();

            foreach (string info in participantInfo)
            {
                string[] infoParts = info.Split();
                int grade = int.Parse(infoParts[2]);

                if (grade != 11 && grade != 10)
                {
                    topNon11thOr10thGradeParticipants.Add(participant.Key);
                    break;
                }
            }
        }

        topNon11thOr10thGradeParticipants.Sort();
        return topNon11thOr10thGradeParticipants;
    }
}
