using System;
using System.Collections.Generic;
using System.Linq;

class Participant
{
    public long Id { get; set; }
    public string Gender { get; set; }
    public int Grade { get; set; }
    public int Age { get; set; }
    public int Score { get; set; }
}

class Program
{
    static void Main(string[] args)
    {
        int n = int.Parse(Console.ReadLine()); // Number of participants
        List<Participant> participants = new List<Participant>();

        // Reading participants' information
        for (int i = 0; i < n; i++)
        {
            string[] participantInfo = Console.ReadLine().Split();
            Participant participant = new Participant
            {
                Id = long.Parse(participantInfo[0]),
                Gender = participantInfo[1],
                Grade = int.Parse(participantInfo[2]),
                Age = int.Parse(participantInfo[3]),
                Score = int.Parse(participantInfo[4])
            };
            participants.Add(participant);
        }

        int m = int.Parse(Console.ReadLine()); // Number of olympiads to process
        List<string> olympiads = new List<string>();

        // Reading olympiad names
        for (int i = 0; i < m; i++)
        {
            olympiads.Add(Console.ReadLine());
        }

        // Process each olympiad
        foreach (var olympiad in olympiads)
        {
            List<long> team = new List<long>();

            // Determine participants for each olympiad
            switch (olympiad)
            {
                case "IOI":
                case "CEOI":
                    var topParticipants = participants.OrderByDescending(p => p.Score).Take(4);
                    foreach (var participant in topParticipants)
                    {
                        team.Add(participant.Id);
                    }
                    break;
                case "EGOI":
                    var femaleParticipants = participants.Where(p => p.Gender == "female").OrderByDescending(p => p.Score).Take(4);
                    foreach (var participant in femaleParticipants)
                    {
                        team.Add(participant.Id);
                    }
                    break;
                case "EJOI":
                    var youngParticipants = participants.Where(p => p.Age <= 15).OrderByDescending(p => p.Score).Take(4);
                    foreach (var participant in youngParticipants)
                    {
                        team.Add(participant.Id);
                    }
                    break;
                case "BaltOI":
                    var topBalticParticipants = participants.OrderByDescending(p => p.Score).Take(6);
                    foreach (var participant in topBalticParticipants)
                    {
                        team.Add(participant.Id);
                    }
                    break;
                case "BalkOI":
                    var nonEleventhGraders = participants.Where(p => p.Grade != 11).OrderByDescending(p => p.Score).Take(4);
                    foreach (var participant in nonEleventhGraders)
                    {
                        team.Add(participant.Id);
                    }
                    break;
                case "JBOI":
                    var nonTenthEleventhGraders = participants.Where(p => p.Grade != 11 && p.Grade != 10).OrderByDescending(p => p.Score).Take(4);
                    foreach (var participant in nonTenthEleventhGraders)
                    {
                        team.Add(participant.Id);
                    }
                    break;
                default:
                    break;
            }

            // Output the team for the current olympiad
            Console.WriteLine(olympiad);
            foreach (var participantId in team.OrderBy(id => id))
            {
                Console.WriteLine(participantId);
            }
        }
    }
}