#include <iostream>
#include <unordered_map>
#include <vector>
#include <algorithm>

using namespace std;

// Function to filter participants based on criteria
vector<int> filter_participants(const unordered_map<string, string>& criteria, int limit, const unordered_map<int, unordered_map<string, int>>& participants) {
    vector<pair<int, int>> scores;
    
    for (const auto& participant : participants) {
        bool match = true;

        for (const auto& criterion : criteria) {
            const string& key = criterion.first;
            const string& value = criterion.second;

            if (key == "gender" && to_string(participants.at(participant.first).at(key)) != value) {
                match = false;
                break;
            }

            if (key == "age" && participants.at(participant.first).at(key) != stoi(value)) {
                match = false;
                break;
            }

            if (key == "grade" && participants.at(participant.first).at(key) != stoi(value)) {
                match = false;
                break;
            }
        }

        if (match) {
            scores.emplace_back(participant.first, participants.at(participant.first).at("score"));
        }
    }

    sort(scores.begin(), scores.end(), [](const auto& a, const auto& b) {
        return a.second > b.second || (a.second == b.second && a.first < b.first);
    });

    vector<int> result;
    for (int i = 0; i < min(limit, static_cast<int>(scores.size())); ++i) {
        result.push_back(scores[i].first);
    }

    return result;
}

int main() {
    int n;
    cin >> n;

    unordered_map<int, unordered_map<string, int>> participants;

    for (int i = 0; i < n; ++i) {
        int participant_id, grade, age, score;
        string gender;
        cin >> participant_id >> gender >> grade >> age >> score;
        participants[participant_id] = {{"gender", gender == "female" ? 1 : 0}, {"grade", grade}, {"age", age}, {"score", score}};
    }

    int m;
    cin >> m;

    for (int i = 0; i < m; ++i) {
        string olympiad_name;
        cin >> olympiad_name;

        vector<int> team_members;

        if (olympiad_name == "IOI" || olympiad_name == "CEOI" || olympiad_name == "BaltOI") {
            team_members = filter_participants({}, 4, participants);
        } else if (olympiad_name == "EGOI") {
            team_members = filter_participants({{"gender", "1"}}, 4, participants);
        } else if (olympiad_name == "EJOI") {
            team_members = filter_participants({{"age", "15"}}, 4, participants);
        } else if (olympiad_name == "JBOI") {
            team_members = filter_participants({{"grade", "10"}, {"grade", "11"}}, 4, participants);
        }

        cout << olympiad_name << endl;
        for (int member_id : team_members) {
            cout << member_id << endl;
        }
    }

    return 0;
}
