#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

typedef long long ll;

// Функція для знаходження найбільшого підвідрізку із невикористаних кольорів
pair<ll, ll> findLongestSegment(const vector<ll>& circle) {
    ll max_length = 0, start = 0, end = 0, current_start = 0;
    ll n = circle.size();
    
    for (ll i = 0; i < n; i++) {
        if (circle[i] == 1) { // колір вже використаний
            if (i - current_start > max_length) {
                max_length = i - current_start;
                start = current_start;
                end = i - 1;
            }
            current_start = i + 1;
        }
    }

    // Перевірка для останнього сегмента
    if (n - current_start > max_length) {
        start = current_start;
        end = n - 1;
    }

    return {start, end};
}

int main() {
    ll n, m;
    cin >> n >> m; // Кількість кіл та кількість кольорів для вибору

    vector<vector<ll>> circles(n);

    for (ll i = 0; i < n; i++) {
        ll a;
        cin >> a; // Кількість кольорів у кожному колі (a_i + 1)
        circles[i].resize(a + 1, 0); // Ініціалізація кожного кругу невикористаними кольорами
        circles[i][0] = 1; // Перший колір у кожному крузі вважаємо використаним
    }

    // Алгоритм вибору кольорів
    for (ll i = 0; i < m; i++) {
        ll max_segment_length = 0;
        pair<ll, ll> max_segment;
        ll circle_index = -1;

        // Пошук найбільшого підвідрізку
        for (ll j = 0; j < n; j++) {
            auto segment = findLongestSegment(circles[j]);
            ll segment_length = segment.second - segment.first + 1;
            if (segment_length > max_segment_length) {
                max_segment_length = segment_length;
                max_segment = segment;
                circle_index = j;
            }
        }

        // Вибір кольору
        if (max_segment_length > 0) {
            ll color_index;
            if (max_segment_length % 2 == 0) {
                color_index = max_segment.first + max_segment_length / 2 - 1; // Вибір одного з двох середніх кольорів
            } else {
                color_index = max_segment.first + max_segment_length / 2; // Вибір середнього кольору
            }
            circles[circle_index][color_index] = 1; // Позначаємо колір як використаний
        }
    }

    // Знаходимо максимальну довжину підвідрізку після вибору (m+n)-го кольору
    ll max_segment_length_after = 0;
    for (ll j = 0; j < n; j++) {
        auto segment = findLongestSegment(circles[j]);
        ll segment_length = segment.second - segment.first + 1;
        if (segment_length > max_segment_length_after) {
            max_segment_length_after = segment_length;
        }
    }

    cout << max_segment_length_after << endl;

    return 0;
}
