import java.util.*;

class Participant {
    int id, grade, age, score;
    String gender;

    public Participant(int id, String gender, int grade, int age, int score) {
        this.id = id;
        this.gender = gender;
        this.grade = grade;
        this.age = age;
        this.score = score;
    }
}

public class Main {
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);

        int n = scanner.nextInt();
        List<Participant> participants = new ArrayList<>();

        for (int i = 0; i < n; i++) {
            int id = scanner.nextInt();
            String gender = scanner.next();
            int grade = scanner.nextInt();
            int age = scanner.nextInt();
            int score = scanner.nextInt();
            participants.add(new Participant(id, gender, grade, age, score));
        }

        int m = scanner.nextInt();
        for (int i = 0; i < m; i++) {
            String olympiad = scanner.next();
            List<Integer> teamIds = getTeamIds(participants, olympiad);
            System.out.println(olympiad);
            for (int id : teamIds) {
                System.out.println(id);
            }
        }
    }

    private static List<Integer> getTeamIds(List<Participant> participants, String olympiad) {
        List<Integer> teamIds = new ArrayList<>();
        switch (olympiad) {
            case "IOI":
            case "CEOI":
                participants.sort(Comparator.comparingInt((Participant p) -> p.score).reversed().thenComparingInt(p -> p.id));
                break;
            case "EGOI":
                participants.sort(Comparator.comparingInt((Participant p) -> p.score).reversed().thenComparingInt(p -> p.id));
                participants = filterByGender(participants, "female");
                break;
            case "EJOI":
                participants.sort(Comparator.comparingInt((Participant p) -> p.score).reversed().thenComparingInt(p -> p.id));
                participants = filterByAge(participants, 15);
                break;
            case "BaltOI":
                participants.sort(Comparator.comparingInt((Participant p) -> p.score).reversed().thenComparingInt(p -> p.id));
                break;
            case "BalkOI":
                participants.sort(Comparator.comparingInt((Participant p) -> p.score).reversed().thenComparingInt(p -> p.id));
                participants = filterByGrade(participants, 11);
                break;
            case "JBOI":
                participants.sort(Comparator.comparingInt((Participant p) -> p.score).reversed().thenComparingInt(p -> p.id));
                participants = filterByGrade(participants, 10);
                break;
        }

        int teamSize = getTeamSize(olympiad);
        for (int i = 0; i < Math.min(teamSize, participants.size()); i++) {
            teamIds.add(participants.get(i).id);
        }

        return teamIds;
    }

    private static List<Participant> filterByGender(List<Participant> participants, String gender) {
        return participants.stream().filter(p -> p.gender.equals(gender)).collect(ArrayList::new, ArrayList::add, ArrayList::addAll);
    }

    private static List<Participant> filterByAge(List<Participant> participants, int maxAge) {
        return participants.stream().filter(p -> p.age <= maxAge).collect(ArrayList::new, ArrayList::add, ArrayList::addAll);
    }

    private static List<Participant> filterByGrade(List<Participant> participants, int grade) {
        return participants.stream().filter(p -> p.grade != grade).collect(ArrayList::new, ArrayList::add, ArrayList::addAll);
    }

    private static int getTeamSize(String olympiad) {
        switch (olympiad) {
            case "IOI":
            case "CEOI":
            case "EGOI":
            case "EJOI":
            case "BalkOI":
            case "JBOI":
                return 4;
            case "BaltOI":
                return 6;
            default:
                return 0;
        }
    }
}