import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Scanner;

class Participant {
    int id;
    String gender;
    int grade;
    int age;
    int score;

    public Participant(int id, String gender, int grade, int age, int score) {
        this.id = id;
        this.gender = gender;
        this.grade = grade;
        this.age = age;
        this.score = score;
    }
}

public class Main {
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);

        int n = scanner.nextInt();
        List<Participant> participants = new ArrayList<>();

        for (int i = 0; i < n; i++) {
            int id = scanner.nextInt();
            String gender = scanner.next();
            int grade = scanner.nextInt();
            int age = scanner.nextInt();
            int score = scanner.nextInt();

            participants.add(new Participant(id, gender, grade, age, score));
        }

        int m = scanner.nextInt();
        for (int i = 0; i < m; i++) {
            String olympiad = scanner.next();
            List<Integer> teamIds = getTeamIds(participants, olympiad);
            Collections.sort(teamIds);

            System.out.println(olympiad);
            for (int id : teamIds) {
                System.out.println(id);
            }
        }
    }

    private static List<Integer> getTeamIds(List<Participant> participants, String olympiad) {
        List<Participant> eligibleParticipants = new ArrayList<>();

        switch (olympiad) {
            case "IOI":
            case "CEOI":
                eligibleParticipants.addAll(participants);
                break;
            case "EGOI":
                for (Participant participant : participants) {
                    if (participant.gender.equals("female")) {
                        eligibleParticipants.add(participant);
                    }
                }
                break;
            case "EJOI":
                for (Participant participant : participants) {
                    if (participant.age <= 15) {
                        eligibleParticipants.add(participant);
                    }
                }
                break;
            case "BaltOI":
            case "JBOI":
                eligibleParticipants.addAll(participants);
                break;
            case "BalkOI":
                for (Participant participant : participants) {
                    if (participant.grade != 11) {
                        eligibleParticipants.add(participant);
                    }
                }
                break;
        }

        Collections.sort(eligibleParticipants, Comparator.comparingInt(p -> -p.score));

        List<Integer> teamIds = new ArrayList<>();
        for (int j = 0; j < Math.min(eligibleParticipants.size(), getTeamSize(olympiad)); j++) {
            teamIds.add(eligibleParticipants.get(j).id);
        }

        return teamIds;
    }

    private static int getTeamSize(String olympiad) {
        Map<String, Integer> teamSizes = new HashMap<>();
        teamSizes.put("IOI", 4);
        teamSizes.put("CEOI", 4);
        teamSizes.put("EGOI", 4);
        teamSizes.put("EJOI", 4);
        teamSizes.put("BaltOI", 6);
        teamSizes.put("BalkOI", 4);
        teamSizes.put("JBOI", 4);

        return teamSizes.get(olympiad);
    }
}