from collections import defaultdict

def process_requests(colors, sizes, inventory, requests):
    remaining_inventory = defaultdict(lambda: defaultdict(int))
    to_be_ordered = defaultdict(lambda: defaultdict(int))

    for color, size, count in inventory.items():
        remaining_inventory[color][size] = count

    for color, size in requests:
        if remaining_inventory[color][size] > 0:
            remaining_inventory[color][size] -= 1
        elif any(remaining_inventory[color][new_size] > 0 for new_size in sizes[size]):
            new_size = next(new_size for new_size in sizes[size] if remaining_inventory[color][new_size] > 0)
            remaining_inventory[color][new_size] -= 1
        else:
            for new_size in sizes[size]:
                if any(remaining_inventory[new_color][new_size] > 0 for new_color in colors):
                    new_color = min(colors)
                    remaining_inventory[new_color][new_size] -= 1
                    break
            else:
                to_be_ordered[color][size] += 1

    return remaining_inventory, to_be_ordered

def print_inventory(inventory):
    for color in sorted(inventory):
        print(*[inventory[color][size] for size in sorted(inventory[color])])

def main():
    n, m = map(int, input().split())
    sizes = {size: list(input().split()) for size in input().split()}

    inventory = defaultdict(lambda: defaultdict(int))
    for _ in range(n):
        row = list(map(int, input().split()))
        for j, count in enumerate(row):
            inventory[i + 1][sizes[size][j]] = count

    k = int(input())
    requests = [tuple(input().split()) for _ in range(k)]

    remaining_inventory, to_be_ordered = process_requests(range(1, n + 1), sizes, inventory, requests)

    print_inventory(remaining_inventory)
    print_inventory(to_be_ordered)

if __name__ == "__main__":
    main()
