#include <iostream>
#include <vector>
#include <algorithm>
#include <unordered_map>

using namespace std;

struct Participant {
    int id;
    string gender;
    int grade;
    int age;
    int score;
};

bool compareParticipants(const Participant& p1, const Participant& p2) {
    return p1.score > p2.score || (p1.score == p2.score && p1.id < p2.id);
}

vector<int> selectTeam(const vector<Participant>& participants, int teamSize, const string& genderFilter, int ageLimit) {
    vector<int> teamIds;
    int selectedCount = 0;

    for (const auto& participant : participants) {
        if (selectedCount == teamSize) {
            break;
        }

        if (participant.gender == genderFilter && participant.age <= ageLimit) {
            teamIds.push_back(participant.id);
            ++selectedCount;
        }
    }

    return teamIds;
}

int main() {
    int n;
    cin >> n;

    vector<Participant> participants(n);
    unordered_map<string, vector<int>> olympiadTeams;

    for (int i = 0; i < n; ++i) {
        cin >> participants[i].id >> participants[i].gender >> participants[i].grade >> participants[i].age >> participants[i].score;
    }

    sort(participants.begin(), participants.end(), compareParticipants);

    int m;
    cin >> m;

    for (int i = 0; i < m; ++i) {
        string olympiad;
        cin >> olympiad;

        if (olympiadTeams.find(olympiad) == olympiadTeams.end()) {
            int teamSize;
            string genderFilter = "male";
            int ageLimit = 20;

            if (olympiad == "EGOI") {
                genderFilter = "female";
            } else if (olympiad == "EJOI") {
                ageLimit = 15;
            } else if (olympiad == "BaltOI") {
                teamSize = 6;
            } else if (olympiad == "BalkOI") {
                teamSize = 4;
                ageLimit = 11;
            } else if (olympiad == "JBOI") {
                teamSize = 4;
                ageLimit = 11;
            } else {
                teamSize = 4;
            }

            olympiadTeams[olympiad] = selectTeam(participants, teamSize, genderFilter, ageLimit);
        }

        for (int id : olympiadTeams[olympiad]) {
            cout << id << endl;
        }
    }

    return 0;
}
